@@ -1,5 +1,5 @@
 mgfhypoexp <- function(x, rate = 1.0, difforder = 0L) {
-    difforder <- match(difforder, 0L:2L, 4L)
+    difforder <- match(as.integer(difforder), 0L:2L, 4L)
     is.na(x)  <- (x >= min(rate))
     inv.diff  <- 1.0 / outer(rate, x, '-')
     prod(rate) * apply(inv.diff, 2L, prod) * switch(difforder,
